==============================
Peek Platform - Server Service
==============================

The Peek Server service is where Peek Apps can run their user interface.
This is the for this service, for the browser side see peek_admin.